# 2023.02.0

**Released on February 21st, 2023**

[Documentation for this release](https://cotainr.readthedocs.org/en/2023.02.0/)

Minor release to fix an issue.

## Bug fixes

- Changed shebang in cotainr script to always point to python3
